# $Id: function.t,v 1.1 2002/09/02 21:07:04 comdog Exp $

use Test::More tests => 2;
use Test::Data qw(Function);

sub fooey($$) { 1 }

prototype_ok( &fooey, '$$', 'Double scalar fooey' );
prototype_ok( &fooey, '$$' );

